﻿using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Linq;
using System.Reflection;
using System.Security.Cryptography;
using System.Text;
using System.Web;
using TestPaymentGatwayLib.Attribute;
using static TestPaymentGatwayLib.Model.PaymentGatwayModel;

namespace TestPaymentGatwayLib.Helper
{
    public class UtilityHelper
    {
        private static TimeZoneInfo India_Standard_Time = TimeZoneInfo.FindSystemTimeZoneById("India Standard Time");
        private UtilityHelper()
        {

        }

        public static string calculateHashFromString(string stringValue, String hashAlgorithmName)
        {
            HashAlgorithm hashAlgorithm = HashAlgorithm.Create(hashAlgorithmName.Length == 0 ? "SHA1" : hashAlgorithmName);
            StringBuilder sb = new StringBuilder();
            byte[] stringValueBytes = Encoding.ASCII.GetBytes(stringValue.ToString());
            int stringValueBytesLength = stringValueBytes.Length;

            for (int i = 0; i < stringValueBytesLength; i++)
            {
                sb.Append(forDigit((stringValueBytes[i] & 240) >> 4, 16));
                sb.Append(forDigit((stringValueBytes[i] & 15), 16));
            }

            stringValueBytes = Encoding.ASCII.GetBytes((new StringBuilder(sb.ToString()).ToString()));

            if (hashAlgorithm != null)
            {
                hashAlgorithm.TransformFinalBlock(stringValueBytes, 0, stringValueBytes.Length);
                byte[] hash = hashAlgorithm.Hash;
                return BitConverter.ToString(hash).Replace("-", "").ToLower();
            }
            return string.Empty;
        }
        public static string GetPaymentRefId()
        {
            string subRefId = string.Concat("WLR",DateTime.Now.ToString("yyMMddHHmmss"));
            return subRefId;
        }

        private static char forDigit(int digit, int radix)
        {
            int MIN_RADIX = 2, MAX_RADIX = 36;
            if ((digit >= radix) || (digit < 0))
            {
                return '\0';
            }
            if ((radix < MIN_RADIX) || (radix > MAX_RADIX))
            {
                return '\0';
            }
            if (digit < 10)
            {
                return (char)('0' + digit);
            }
            return (char)('a' - 10 + digit);
        }

        public static DateTime GetIndiaTimeZoneDatetIme()
        {
            DateTime dateTime_India = TimeZoneInfo.ConvertTimeFromUtc(DateTime.UtcNow, India_Standard_Time);
            return dateTime_India;
        }

        public static object BindPaymenModel(object obj)
        {
            var RequestObj = HttpContext.Current.Request.Form;
            foreach (PropertyInfo prop in obj.GetType().GetProperties())
            {
                var attrs = prop.GetCustomAttributes().ToList();
                if (attrs.Count > 0)
                {
                    foreach (var attr in attrs)
                    {
                        string apifield = ((PaymentAttribute)attr).ApiFieldName;
                        prop.SetValue(obj, RequestObj[apifield]);
                    }
                }
            }

            return obj;
        }

        public static object BindPaymenModel(object obj, NameValueCollection RequestObj)
        {
            foreach (PropertyInfo prop in obj.GetType().GetProperties())
            {
                var attrs = prop.GetCustomAttributes().ToList();
                if (attrs.Count > 0)
                {
                    foreach (var attr in attrs)
                    {
                        string apifield = ((PaymentAttribute)attr).ApiFieldName;
                        prop.SetValue(obj, RequestObj[apifield]);
                    }
                }
            }

            return obj;
        }
    }
}