﻿using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Linq;
using System.Web;
using TestPaymentGatwayLib.Attribute;
using TestPaymentGatwayLib.Helper;

namespace TestPaymentGatwayLib.Model
{
    public class PaymentGatwayModel
    {
        public class CustomerInformationModel
        {
            public string StoreName { get; set; }
            public string sharedSecret { get; set; }
            public string ChargeTotal { get; set; }
            public string Currency { get; set; }
            public string TransactionReferenceId { get; set; }
            public string Action { get; set; }
            public string SuccessReturnUrl { get; set; }
            public string FailureReturnUrl { get; set; }
            public string TransactionTimestamp { get; set; }
            public string PaymentRefId { get; set; }

            public string GSTPanNumber { get; set; }
            public string Remarks { get; set; }
            public string CustomerCode { get; set; }
            public string Email { get; set; }
            public string Invoice { get; set; }
            public string ContactPerson { get; set; }
            public string PayerType { get; set; }
            public string CcAvenueCheckoutUrl { get; set; }
            public string CcAvenueAccessCode { get; set; }
            public string encRequest { get; set; }
        }

        public class PaymentFailureModel
        {
            [PaymentAttribute(ApiFieldName = "approval_code")]
            public string ApprovalCode { get; set; }
            [PaymentAttribute(ApiFieldName = "txndate_processed")]
            public string ProcessedTransactionDate { get; set; }
            [PaymentAttribute(ApiFieldName = "timezone")]
            public string TimeZone { get; set; }

            [PaymentAttribute(ApiFieldName = "response_hash")]
            public string ResponseId { get; set; }

            [PaymentAttribute(ApiFieldName = "fail_rc")]
            public string FailRc { get; set; }

            [PaymentAttribute(ApiFieldName = "oid", Description = "OID Is TransactionReferenceId")]
            public string OID { get; set; }

            [PaymentAttribute(ApiFieldName = "tdate")]
            public string TransactionDate { get; set; }

            [PaymentAttribute(ApiFieldName = "installments_interest")]
            public string InstallmentsInterest { get; set; }

            [PaymentAttribute(ApiFieldName = "cccountry")]
            public string Country { get; set; }

            [PaymentAttribute(ApiFieldName = "ccbrand")]
            public string Brand { get; set; }

            [PaymentAttribute(ApiFieldName = "txntype")]
            public string txtType { get; set; }

            [PaymentAttribute(ApiFieldName = "currency")]
            public string Currency { get; set; }

            [PaymentAttribute(ApiFieldName = "txndatetime")]
            public string txnDateTime { get; set; }

            [PaymentAttribute(ApiFieldName = "ipgTransactionId")]
            public string PaymentGatwayTransactionId { get; set; }

            [PaymentAttribute(ApiFieldName = "fail_reason")]
            public string FailedReason { get; set; }

            [PaymentAttribute(ApiFieldName = "chargetotal")]
            public string TotalAmount { get; set; }

            [PaymentAttribute(ApiFieldName = "status")]
            public string Status { get; set; }

            private string _CCAvenueResponse = string.Empty;
            [PaymentAttribute(ApiFieldName = "encResp")]
            public string CCAvenueResponse
            {
                get
                {
                    string para = (new CCACrypto()).Decrypt(_CCAvenueResponse, ConstantHelper.CcAvenueWorkingKey);
                    var objResponse = new CCAvenueResponseModel();
                    NameValueCollection response = HttpUtility.ParseQueryString(para);
                    UtilityHelper.BindPaymenModel(objResponse, response);
                    this.CCAvenueFailureResponse = objResponse;
                    return para;
                }
                set
                {
                    _CCAvenueResponse = value;
                }
            }

            [PaymentAttribute(ApiFieldName = "orderNo")]
            public string CCAvenueOrderNo
            {
                get;
                set;
            }

            [PaymentAttribute(ApiFieldName = "CCAvenureResponse")]
            public CCAvenueResponseModel CCAvenueFailureResponse
            {
                get;
                set;
            }

        }

        public class CCAvenueResponseModel
        {
            [PaymentAttribute(ApiFieldName = "order_id")]
            public string order_id { get; set; }
            [PaymentAttribute(ApiFieldName = "tracking_id")]
            public string tracking_id { get; set; }
            [PaymentAttribute(ApiFieldName = "bank_ref_no")]
            public string bank_ref_no { get; set; }
            [PaymentAttribute(ApiFieldName = "order_status")]
            public string order_status { get; set; }
            [PaymentAttribute(ApiFieldName = "failure_message")]
            public string failure_message { get; set; }
            [PaymentAttribute(ApiFieldName = "payment_mode=null")]
            public string payment_mode { get; set; }
            [PaymentAttribute(ApiFieldName = "card_name=null")]
            public string card_name { get; set; }
            [PaymentAttribute(ApiFieldName = "status_code")]
            public string status_code { get; set; }
            [PaymentAttribute(ApiFieldName = "status_message")]
            public string status_message { get; set; }
            [PaymentAttribute(ApiFieldName = "currency")]
            public string currency { get; set; }
            [PaymentAttribute(ApiFieldName = "amount")]
            public string amount { get; set; }
            [PaymentAttribute(ApiFieldName = "billing_name")]
            public string billing_name { get; set; }
            [PaymentAttribute(ApiFieldName = "billing_address")]
            public string billing_address { get; set; }
            [PaymentAttribute(ApiFieldName = "billing_city")]
            public string billing_city { get; set; }
            [PaymentAttribute(ApiFieldName = "billing_state")]
            public string billing_state { get; set; }
            [PaymentAttribute(ApiFieldName = "billing_zip")]
            public string billing_zip { get; set; }
            [PaymentAttribute(ApiFieldName = "billing_country")]
            public string billing_country { get; set; }
            [PaymentAttribute(ApiFieldName = "billing_tel")]
            public string billing_tel { get; set; }
            [PaymentAttribute(ApiFieldName = "billing_email")]
            public string billing_email { get; set; }
            [PaymentAttribute(ApiFieldName = "delivery_name")]
            public string delivery_name { get; set; }
            [PaymentAttribute(ApiFieldName = "delivery_address")]
            public string delivery_address { get; set; }
            [PaymentAttribute(ApiFieldName = "delivery_city")]
            public string delivery_city { get; set; }
            [PaymentAttribute(ApiFieldName = "delivery_state")]
            public string delivery_state { get; set; }
            [PaymentAttribute(ApiFieldName = "delivery_zip")]
            public string delivery_zip { get; set; }
            [PaymentAttribute(ApiFieldName = "delivery_country")]
            public string delivery_country { get; set; }
            [PaymentAttribute(ApiFieldName = "delivery_tel")]
            public string delivery_tel { get; set; }
            [PaymentAttribute(ApiFieldName = "merchant_param1")]
            public string merchant_param1 { get; set; }
            [PaymentAttribute(ApiFieldName = "merchant_param2")]
            public string merchant_param2 { get; set; }
            [PaymentAttribute(ApiFieldName = "merchant_param3")]
            public string merchant_param3 { get; set; }
            [PaymentAttribute(ApiFieldName = "merchant_param4")]
            public string merchant_param4 { get; set; }
            [PaymentAttribute(ApiFieldName = "merchant_param5")]
            public string merchant_param5 { get; set; }
            [PaymentAttribute(ApiFieldName = "vault")]
            public string vault { get; set; }
            [PaymentAttribute(ApiFieldName = "offer_type")]
            public string offer_type { get; set; }
            [PaymentAttribute(ApiFieldName = "offer_code")]
            public string offer_code { get; set; }
            [PaymentAttribute(ApiFieldName = "discount_value")]
            public string discount_value { get; set; }
            [PaymentAttribute(ApiFieldName = "mer_amount")]
            public string mer_amount { get; set; }
            [PaymentAttribute(ApiFieldName = "eci_value")]
            public string eci_value { get; set; }
            [PaymentAttribute(ApiFieldName = "retry")]
            public string retry { get; set; }
            [PaymentAttribute(ApiFieldName = "response_code")]
            public string response_code { get; set; }
            [PaymentAttribute(ApiFieldName = "billing_notes")]
            public string billing_notes { get; set; }
            [PaymentAttribute(ApiFieldName = "trans_date")]
            public string trans_date { get; set; }
            [PaymentAttribute(ApiFieldName = "bin_country")]
            public string bin_country { get; set; }

        }

        public class PaymentSuccesseModel
        {
            [PaymentAttribute(ApiFieldName = "oid", Description = "OID Is TransactionReferenceId")]
            public string OID { get; set; }

            [PaymentAttribute(ApiFieldName = "status")]
            public string Status { get; set; }

            [PaymentAttribute(ApiFieldName = "endpointTransactionId")]
            public string EndPointTransactionId { get; set; }

            [PaymentAttribute(ApiFieldName = "approval_code")]
            public string ApprovalCode { get; set; }

            [PaymentAttribute(ApiFieldName = "terminal_id")]
            public string TerminalId { get; set; }

            [PaymentAttribute(ApiFieldName = "ipgTransactionId")]
            public string IPGTransactionId { get; set; }

            [PaymentAttribute(ApiFieldName = "processor_response_code")]
            public string ProcessorResponseCode { get; set; }

            [PaymentAttribute(ApiFieldName = "fail_reason")]
            public string FailReason { get; set; }

            [PaymentAttribute(ApiFieldName = "txndatetime")]
            public string TransactionDateTime { get; set; }

            [PaymentAttribute(ApiFieldName = "txndate_processed")]
            public string TransactionDateProcessed { get; set; }

            [PaymentAttribute(ApiFieldName = "paymentMethod")]
            public string PaymentMethod { get; set; }

            [PaymentAttribute(ApiFieldName = "chargetotal")]
            public string TransactionAmount { get; set; }


            private string _CCAvenueResponse = string.Empty;
            [PaymentAttribute(ApiFieldName = "encResp")]
            public string CCAvenueResponse
            {
                get
                {
                    string para = (new CCACrypto()).Decrypt(_CCAvenueResponse, ConstantHelper.CcAvenueWorkingKey);
                    var objResponse = new CCAvenueResponseModel();
                    NameValueCollection response = HttpUtility.ParseQueryString(para);
                    UtilityHelper.BindPaymenModel(objResponse, response);
                    this.CCAvenueFailureResponse = objResponse;
                    return para;
                }
                set
                {
                    _CCAvenueResponse = value;
                }
            }

            [PaymentAttribute(ApiFieldName = "orderNo")]
            public string CCAvenueOrderNo
            {
                get;
                set;
            }

            [PaymentAttribute(ApiFieldName = "CCAvenureResponse")]
            public CCAvenueResponseModel CCAvenueFailureResponse
            {
                get;
                set;
            }
        }

        public class PaymentRefund
        {
            public string TransactionReferenceId { get; set; }
            public string ChargeTotal { get; set; }
            public string StoreName { get; set; }
        }
        public enum CurrencyCode
        {
            INR = 356, GBP = 896, EUR = 978
        }
    }
}